# Django Global Requests

Allows for global request objects in your django project

## Installation

`pip install django-guardian-queryset`

## Configuration

1. Add to installed apps:

    ```
    INSTALLED_APPS = [
         ...
         'guardian_queryset',
    ]
    ```
